You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@shardingsphere.apache.org by ji...@apache.org on 2022/06/26 03:35:21 UTC

[shardingsphere] branch master updated: Modify the parameter name to match the actual parameter type (#18600)

This is an automated email from the ASF dual-hosted git repository.

jianglongtao pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/shardingsphere.git


The following commit(s) were added to refs/heads/master by this push:
     new f1509554b72 Modify the parameter name to match the actual parameter type (#18600)
f1509554b72 is described below

commit f1509554b72caf07d7572f558fe674de325329f5
Author: jiangML <10...@qq.com>
AuthorDate: Sun Jun 26 11:35:12 2022 +0800

    Modify the parameter name to match the actual parameter type (#18600)
---
 .../mode/metadata/persist/MetaDataPersistService.java               | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/shardingsphere-mode/shardingsphere-mode-core/src/main/java/org/apache/shardingsphere/mode/metadata/persist/MetaDataPersistService.java b/shardingsphere-mode/shardingsphere-mode-core/src/main/java/org/apache/shardingsphere/mode/metadata/persist/MetaDataPersistService.java
index c71ad28a7c7..b3b45910346 100644
--- a/shardingsphere-mode/shardingsphere-mode-core/src/main/java/org/apache/shardingsphere/mode/metadata/persist/MetaDataPersistService.java
+++ b/shardingsphere-mode/shardingsphere-mode-core/src/main/java/org/apache/shardingsphere/mode/metadata/persist/MetaDataPersistService.java
@@ -75,16 +75,16 @@ public final class MetaDataPersistService {
     /**
      * Persist configurations.
      *
      * @param schemaConfigs schema configurations
      * @param globalRuleConfigs global rule configurations
      * @param props properties
      * @param isOverwrite whether overwrite registry center's configuration if existed
      */
-    public void persistConfigurations(final Map<String, ? extends DatabaseConfiguration> schemaConfigs,
+    public void persistConfigurations(final Map<String, ? extends DatabaseConfiguration> databaseConfigs,
                                       final Collection<RuleConfiguration> globalRuleConfigs, final Properties props, final boolean isOverwrite) {
         globalRuleService.persist(globalRuleConfigs, isOverwrite);
         propsService.persist(props, isOverwrite);
-        for (Entry<String, ? extends DatabaseConfiguration> entry : schemaConfigs.entrySet()) {
+        for (Entry<String, ? extends DatabaseConfiguration> entry : databaseConfigs.entrySet()) {
             String databaseName = entry.getKey();
             Map<String, DataSourceProperties> dataSourcePropertiesMap = getDataSourcePropertiesMap(entry.getValue().getDataSources());
             Collection<RuleConfiguration> ruleConfigurations = entry.getValue().getRuleConfigurations();
@@ -75,16 +75,16 @@ public final class MetaDataPersistService {
      * Persist configurations.
      *
-     * @param schemaConfigs schema configurations
+     * @param databaseConfigs database configurations
      * @param globalRuleConfigs global rule configurations
      * @param props properties